netapp_ontap.models.key_server_readcreate API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.key_server_readcreate`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class KeyServerReadcreateSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the KeyServerReadcreate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `connectivity: KeyServerStateArray GET`

    A container for holding an array of the key server connectivity state for each node.

  `links: SelfLink GET`

    The links field of the key_server_readcreate.

  `secondary_key_servers: str GET`

    A comma delimited string of the secondary key servers associated with the primary key server.

    Example: secondary1.com, 10.2.3.4

  `server: str GET POST`

    External key server for key management. If no port is provided, a default port of 5696 is used.

    Example: keyserver1.com:5698

  `timeout: Size GET`

    I/O timeout in seconds for communicating with the key server.

    Example: 60

  `username: str GET`

    Username credentials for connecting with the key server.

    Example: admin